@@ -1,4 +1,6 @@
 package MIME::Decoder::NBit;
+use strict;
+use warnings;
 
 
 =head1 NAME
@@ -96,7 +98,7 @@ use MIME::Tools qw(:msgs);
 @ISA = qw(MIME::Decoder);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.502";
+$VERSION = "5.503";
 
 ### How many bytes to decode at a time?
 my $DecodeChunkLength = 8 * 1024;
